import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

from typeguard import check_type

import aws_cdk._jsii
import aws_prototyping_sdk.pdk_nag._jsii
import cdk_nag._jsii
import constructs._jsii
import projen._jsii

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "@aws-prototyping-sdk/open-api-gateway",
    "0.17.2",
    __name__[0:-6],
    "open-api-gateway@0.17.2.jsii.tgz",
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
